RecordWriter
============

.. currentmodule:: parquetranger

.. autoclass:: RecordWriter
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~RecordWriter.record_limit

   .. rubric:: Methods Summary

   .. autosummary::

      ~RecordWriter.add_to_batch
      ~RecordWriter.close
      ~RecordWriter.writer_function

   .. rubric:: Attributes Documentation

   .. autoattribute:: record_limit

   .. rubric:: Methods Documentation

   .. automethod:: add_to_batch
   .. automethod:: close
   .. automethod:: writer_function
